@@ -1,6 +1,6 @@
 package Workflow;
 
-# $Id: Workflow.pm 527 2010-08-06 06:28:33Z jonasbn $
+# $Id: Workflow.pm 570 2012-11-08 21:53:22Z jonasbn $
 
 use warnings;
 use strict;
@@ -13,9 +13,10 @@ use Carp qw(croak carp);
 use English qw( -no_match_vars );
 
 my @FIELDS = qw( id type description state last_update time_zone );
-__PACKAGE__->mk_accessors(@FIELDS);
+my @INTERNAL = qw( _factory );
+__PACKAGE__->mk_accessors( @FIELDS, @INTERNAL );
 
-$Workflow::VERSION = '1.34';
+$Workflow::VERSION = '1.35';
 
 use constant NO_CHANGE_VALUE => 'NOCHANGE';
 
@@ -99,10 +100,10 @@ sub execute_action {
         # Jim Brandt 4/16/2008: Implemented transactions for DBI persisters.
         # Implementation still depends on each persister.
 
-        FACTORY->save_workflow($self);
+        $self->_factory()->save_workflow($self);
 
         # If using a DBI persister with no autocommit, commit here.
-        FACTORY->_commit_transaction($self);
+        $self->_factory()->_commit_transaction($self);
 
         $log->is_info
             && $log->info("Saved workflow with possible new state ok");
@@ -119,7 +120,7 @@ sub execute_action {
         );
         $self->state($old_state);
 
-        FACTORY->_rollback_transaction($self);
+        $self->_factory()->_rollback_transaction($self);
 
         # Don't use 'workflow_error' here since $error should already
         # be a Workflow::Exception object or subclass
@@ -183,7 +184,7 @@ sub get_history {
     my @uniq_history = ();
     my %seen_ids     = ();
     my @all_history
-        = ( FACTORY->get_workflow_history($self), @{ $self->{_histories} } );
+        = ( $self->_factory()->get_workflow_history($self), @{ $self->{_histories} } );
     foreach my $history (@all_history) {
         my $id = $history->id;
         if ($id) {
@@ -212,16 +213,18 @@ sub clear_history {
 # PRIVATE METHODS
 
 sub init {
-    my ( $self, $id, $current_state, $config, $wf_state_objects ) = @_;
+    my ( $self, $id, $current_state, $config, $wf_state_objects, $factory ) = @_;
     $id  ||= '';
     $log ||= get_logger();
+    $factory ||= FACTORY;
     $log->info(
         "Instantiating workflow of with ID '$id' and type ",
         "'$config->{type}' with current state '$current_state'"
     );
 
     $self->id($id) if ($id);
-
+    $self->_factory( $factory );    
+    
     $self->state($current_state);
     $self->type( $config->{type} );
     $self->description( $config->{description} );
@@ -277,7 +280,7 @@ sub _get_action {
     $log->is_debug
         && $log->debug("Action '$action_name' exists in state '$state'");
 
-    my $action = FACTORY->get_action( $self, $action_name );
+    my $action = $self->_factory()->get_action( $self, $action_name );
 
     # This will throw an exception which we want to bubble up
 
@@ -438,7 +441,7 @@ This documentation describes version 0.15 of Workflow
 
  # Stock the factory with the configurations; we can add more later if
  # we want
- FACTORY->add_config_from_file(
+ $self->_factory()->add_config_from_file(
      workflow   => $workflow_conf,
      action     => $action_conf,
      condition  => $condition_conf,
@@ -446,7 +449,7 @@ This documentation describes version 0.15 of Workflow
  );
  
  # Instantiate a new workflow...
- my $workflow = FACTORY->create_workflow( 'myworkflow' );
+ my $workflow = $self->_factory()->create_workflow( 'myworkflow' );
  print "Workflow ", $workflow->id, " ",
        "currently at state ", $workflow->state, "\n";
  
@@ -478,9 +481,47 @@ This documentation describes version 0.15 of Workflow
  
  # Later.... fetch an existing workflow
  my $id = get_workflow_id_from_user( ... );
- my $workflow = FACTORY->fetch_workflow( 'myworkflow', $id );
+ my $workflow = $self->_factory()->fetch_workflow( 'myworkflow', $id );
  print "Current state: ", $workflow->state, "\n";
 
+=head1 QUICK START
+
+The F<eg/ticket/> directory contains a configured workflow system. 
+You can access the same data and logic in two ways:
+
+=over
+
+=item * a command-line application (ticket.pl)
+
+=item * a CGI script               (ticket.cgi)
+
+=item * a web application          (ticket_web.pl)
+
+=back
+
+To initialize:
+
+	perl ticket.pl --db
+
+To run the command-line application:
+
+	perl ticket.pl
+
+To access the database and data from CGI, add the relevant
+configuration for your web server and call ticket.cgi:
+
+	http://www.mysite.com/workflow/ticket.cgi
+
+To start up the standalone web server:
+
+	perl ticket_web.pl
+
+(Barring changes to HTTP::Daemon and forking the standalone server
+won't work on Win32; use CGI instead, although patches are always
+welcome.)
+
+For more info, see F<eg/ticket/README>
+
 =head1 DESCRIPTION
 
 =head2 Overview
@@ -618,7 +659,7 @@ so you can ask it what you can do next as well as what is required to
 move on. So to use our ticket example we can do this, creating the
 workflow and asking it what actions we can execute right now:
 
- my $wf = Workflow::Factory->create_workflow( 'Ticket' );
+ my $wf = Workflow::$self->_factory()->create_workflow( 'Ticket' );
  my @actions = $wf->get_current_actions;
 
 We can also interrogate the workflow about what fields are necessary
@@ -1097,6 +1138,33 @@ to L<Workflow::Config>, for implementation details.
 
 =back
 
+=head2 DEPENDENCIES FOR THE EXAMPLE APPLICATION
+
+=over
+
+=item L<CGI>
+
+=item L<CGI::Cookie>
+
+=item L<DBD::SQLite>
+
+=item L<HTTP::Daemon>
+
+=item L<HTTP::Request>
+
+=item L<HTTP::Response>
+
+=item L<HTTP::Status>
+
+=item L<Template> (Template Toolkit)
+
+=back
+
+For Win32 systems you can get the Template Toolkit and DBD::SQLite
+PPDs from TheoryX:
+
+	L<http://theoryx5.uwinnipeg.ca/cgi-bin/ppmserver?urn:/PPMServer58>
+
 =head1 INCOMPATIBILITIES
 
 No special incompatibilies exist, CPAN testers reports however do demonstrate
@@ -1269,7 +1337,7 @@ development. The list is low-traffic.
 
 =over
 
-=item L<http://sourceforge.net/mail/?group_id=177533>
+=item L<http://sourceforge.net/mail/?group_id=177533> (including archive)
 
 =back
 
@@ -1281,7 +1349,8 @@ development. The list is low-traffic.
 
 =item Ohloh news L<https://www.ohloh.net/p/perl-Workflow/messages.rss>
 
-=item CPAN testers reports L<http://cpantesters.perl.org/show/Workflow.rss>
+=item CPAN testers reports L<http://cpantesters.perl.org/show/Workflow.rss> in matrix:
+
 
 =back
 
@@ -1305,8 +1374,19 @@ L<http://search.cpan.org/dist/Workflow>
 
 =head1 SEE ALSO
 
-October 2004 talk 'Workflows in Perl' given to
-pgh.pm: L<http://www.cwinters.com/pdf/workflow_pgh_pm.pdf>
+=over
+
+* November 2010 talk 'Workflow' given at Nordic Perl Workshop 2010 in Reykjavik,
+Iceland by jonasbn 
+L<http://www.slideshare.net/jonasbn/workflow-npw2010>
+
+* August 2010 talk 'Workflow' given at YAPC::Europe 2010 in Pisa, Italy by jonasbn 
+L<http://www.slideshare.net/jonasbn/workflow-yapceu2010>
+
+* October 2004 talk 'Workflows in Perl' given to
+pgh.pm by Chris Winters: L<http://www.cwinters.com/pdf/workflow_pgh_pm.pdf>
+
+=back
 
 =head1 COPYRIGHT
 
@@ -1324,6 +1404,17 @@ Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
 The following folks have also helped out:
 
+Scott Harding, for lazy evaluation of conditions, see Changes file: 1.35
+
+Oliver Welter, patch implementing custom workflows, see Changes file: 1.35
+
+Oliver Welter, patch implementing factory subclassing, see Changes file: 1.35
+
+Scott Harding, for nested conditions, see Changes file: 1.35
+
+Steven van der Vegt, patch for autorun in initial state and improved exception
+handling for validators, see Changes file: 1.34_1
+
 Andrew O'Brien, patch implementing dynamic reloaded of flows, see Changes file:
 1.33
 
@@ -1371,3 +1462,5 @@ to subclass L<Workflow::Factory>) and good ideas.
 
 Martin Winkler E<lt>mw@arsnavigandi.deE<gt> - Pointed out a bug and a
 few other items.
+
+=cut
