@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm 516 2010-01-30 13:41:38Z jonasbn $
+# $Id: State.pm 566 2012-11-08 21:22:56Z jonasbn $
 
 use warnings;
 use strict;
@@ -14,7 +14,7 @@ use English qw( -no_match_vars );
 $Workflow::State::VERSION = '1.15';
 
 my @FIELDS   = qw( state description type );
-my @INTERNAL = qw( _test_condition_count );
+my @INTERNAL = qw( _test_condition_count _factory );
 __PACKAGE__->mk_accessors( @FIELDS, @INTERNAL );
 
 my ($log);
@@ -49,11 +49,9 @@ sub get_available_action_names {
 
     foreach my $action_name (@all_actions) {
 
-        #my $action_group = FACTORY->{_action_config}{$action_name}{'group'};
-
         #From Ivan Paponov
         my $action_group
-            = FACTORY->{_action_config}{ $self->type() }{$action_name}
+            = $self->_factory()->{_action_config}{ $self->type() }{$action_name}
             {'group'};
 
         if ( defined $group && length $group ) {
@@ -166,7 +164,7 @@ sub evaluate_action {
                 # name. As the result has not been cached, we have
                 # to get the real condition with the original
                 # condition name and evaluate that
-                $condition = FACTORY->get_condition( $orig_condition,
+                $condition = $self->_factory()->get_condition( $orig_condition,
                     $self->type() );
             }
             $log->is_debug
@@ -273,7 +271,10 @@ sub may_stop {
 # INTERNAL
 
 sub init {
-    my ( $self, $config ) = @_;
+    my ( $self, $config, $factory ) = @_;
+    
+    # Fallback for old style
+    $factory ||= FACTORY;
     $log ||= get_logger();
     my $name = $config->{name};
 
@@ -283,7 +284,8 @@ sub init {
         && $log->debug("Constructing '$class' object for state $name");
 
     $self->state($name);
-
+    $self->_factory( $factory );
+    
     # Note this is the workflow type.
     $self->type( $config->{type} );
     $self->description( $config->{description} );
@@ -393,7 +395,7 @@ sub _create_condition_objects {
                     && $log->info(
                     "Fetching condition '$condition_info->{name}'");
                 push @condition_objects,
-                    FACTORY->get_condition( $condition_info->{name},
+                    $self->_factory()->get_condition( $condition_info->{name},
                     $self->type() );
             }
         }
